#
# spec file for package apache-commons-csv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           apache-commons-csv
Version:        1.13.0
Release:        1.1
Summary:        A library to read and write files in variations of the Comma Separated Value (CSV) format
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://commons.apache.org/proper/commons-csv/
Source0:        https://dlcdn.apache.org/commons/csv/source/commons-csv-%{version}-src.tar.gz
Source1000:     apache-commons-csv.rpmlintrc
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildArch:      noarch

%description
Commons CSV reads and writes files in variations of the Comma Separated Value (CSV) format.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n commons-csv-%{version}-src

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc RELEASE-NOTES.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt

%changelog
* Fri Jan 24 2025 Gus Kenion <gus.kenion@suse.com>
- Update to version 1.13.0
  * New Features
    + CSV-313: Add CSVPrinter.getRecordCount().
    + Add and use CSVParser.Builder and builder() and deprecate
    CSVParser constructors.
    + CSVFormat.Builder implements Supplier<CSVFormat>.
    + Deprecate CSVFormat.Builder.build() for get().
    + CSV-196: Track byte position #502.
  * Fixed Bugs
    + CSV-314: Required OSGi Import-Package version numbers in
    MANIFEST.MF #504.
    + CSV-314: CSVParser.nextRecord() should throw CSVException (an
    IOException subclass) instead of IOException and
    IllegalStateException, no method signature changes needed.
  * Changes
    + Bump org.apache.commons:commons-parent from 76 to 78 #486,
    [#495].
    + Bump org.codehaus.mojo:taglist-maven-plugin from 3.1.0 to
    3.2.1 #493.
    + Bump commons-io:commons-io from 2.17.0 to 2.18.0 #505.
    + Bump commons-codec:commons-codec from 1.17.1 to 1.17.2.
    + Bump org.apache.commons:commons-parent from 78 to 79.
* Mon Oct 14 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to version 1.12.0
  * New Features
    + CSV-270: Add CSVException that extends IOException thrown on
    invalid input instead of IOException.
  * Fixed Bugs
    + Fix PMD issues for port to PMD 7.1.0.
    + Fix some Javadoc links #442.
    + Extract duplicated code into a method #444.
    + Migrate CSVFormat#print(File, Charset) to NIO #445.
    + Fix documentation for CSVFormat private constructor #466.
    + CSV-294: CSVFormat does not support explicit " as escape
    char.
    + CSV-150: Escaping is not disableable.
    + Fix Javadoc warnings on Java 23.
    + Improve parser performance by up to 20%%, YMMV.
  * Changes
    + Bump commons-codec:commons-codec from 1.16.1 to 1.17.1 #422,
    [#449].
    + Bump org.apache.commons:commons-parent from 69 to 75 #435,
    [#452], #465, #468, #475.
    + Bump org.codehaus.mojo:taglist-maven-plugin from 3.0.0 to
    3.1.0 #441.
    + Bump org.apache.commons:commons-lang3 from 3.14.0 to 3.17.0
    [#450], #459, #470.
    + Bump org.hamcrest:hamcrest from 2.2 to 3.0 #455.
    + Bump commons-io:commons-io from 2.16.1 to 2.17.0 #476.
- Apply fdupes to javadoc directory
* Mon Aug 12 2024 Gus Kenion <gus.kenion@suse.com>
- Update to version 1.11.0:
  * New Features:
    + [Javadoc] Add example to CSVFormat#setHeaderComments() #344.
    Fixes CSV-308.
    + Add and use CSVFormat#setTrailingData(boolean) in
    CSVFormat.EXCEL for Excel compatibility #303.
    + Add and use CSVFormat#setLenientEof(boolean) in
    CSVFormat.EXCEL for Excel compatibility #303.
  * Fixes:
    + Replace deprecated method in user guide, update external link
    [#324], #325. Fixes CSV-306.
    + Document duplicate header behavior #309.
    + Add missing docs #328.
    + [StepSecurity] CI: Harden GitHub Actions #329, #330.
    + Better error message during faulty CSV record read #347.
    Fixes CSV-147.
    + Misleading error message when QuoteMode set to None #352.
    Fixes CSV-310.
    + OutOfMemory for very long rows despite using column value of
    type Reader. Fixes CSV-311.
    + Use try-with-resources to manage JDBC Clob in
    CSVPrinter.printRecords(ResultSet).
    + JDBC Blob columns are now output as Base64 instead of
    Object#toString(), which usually is InputStream#toString().
    + Support unusual Excel use cases: Add support for trailing
    data after the closing quote, and EOF without a final closing
    quote #303.
    + MongoDB CSV empty first column parsing fix #412.
  * Update dependencies:
    + Bump commons-io:commons-io: from 2.11.0 to 2.16.1 #408, #413.
    + Bump commons-parent from 57 to 69 #410.
    + Bump h2 from 2.1.214 to 2.2.224 #333, #349, #359.
    + Bump commons-lang3 from 3.12.0 to 3.14.0.
    + Update exception message in CSVRecord#getNextRecord() #348.
    + Bump tests using com.opencsv:opencsv from 5.8 to 5.9 #373.
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Tue Mar 28 2023 David Anes <david.anes@suse.com>
- Update to version 1.10.0:
  - Minor changes #172. Thanks to Arturo Bernal.
  - No Automatic-Module-Name prevents usage in JPMS projects without repacking the JAR. Fixes CSV-292. Thanks to Rob Vesse.
  - Fix for multi-char delimiter not working as expected #218. Fixes CSV-288. Thanks to Santhsoh, Angus.
  - CSVRecord.get(Enum) should use Enum.name() instead of Enum.toString(). Fixes CSV-269. Thanks to Auke te Winkel, Gary Gregory.
  - Allow org.apache.commons.csv.IOUtils.copy(Reader, Appendable, CharBuffer) to compile on Java 11 and run on Java 8. Thanks to Gary Gregory.
  - CSVRecord.toList() does not give write access to the new List. Fixes CSV-300. Thanks to Markus Spann, Gary Gregory.
  - CSVParser.getRecords() now throws UncheckedIOException instead of IOException. Thanks to Gary Gregory.
  - Add comments to iterator() and stream() #270. Fixes CSV-274. Thanks to Peter Hull, Bruno P. Kinoshita, Gary Gregory.
  - Fix wrong assumptions in PostgreSQL formats #265. Fixes CSV-290. Thanks to angusdev, Gary Gregory.
  - Validate input to setDelimiter(String) for empty string #266. Thanks to Mykola Faryma.
  - Bump CSVFormat#serialVersionUID from 1 to 2. Thanks to Dependabot.
  - CSVParser: Identify duplicates in null, empty and blank header names #279. Thanks to Alex Herbert.
  - Serialization in CSVFormat is not supported from one version to the next.
  - Make CSVRecord#values() public. Fixes CSV-291. Thanks to Gary Gregory.
  - Add DuplicateHeaderMode for flexibility with header strictness. #114. Fixes CSV-264. Thanks to Sagar Tiwari, Seth Falco, Alex Herbert, Gary Gregory.
  - Support for parallelism in CSVPrinter. Fixes CSV-295. Thanks to Gary Gregory.
  - Add CSVPrinter.printRecord[s](Stream). Fixes CSV-295. Thanks to Gary Gregory.
  - Add accessors for header/trailer comments #257. Fixes CSV-304. Thanks to Peter Hull, Bruno P. Kinoshita, Gary Gregory.
  - Add github/codeql-action.
  - Bump actions/cache from 2.1.6 to 3.0.10 #196, #233, #243, #267, #271. Thanks to Dependabot, Gary Gregory.
  - Bump actions/checkout from 2.3.4 to 3.1.0 #188, #195, #220, #272. Thanks to Dependabot, Gary Gregory.
  - Bump actions/setup-java from 2 to 3.5.1. Thanks to Gary Gregory.
  - Bump actions/upload-artifact from 3.1.0 to 3.1.1 #280. Thanks to Dependabot.
  - Bump commons-parent from 52 to 56 #264, #288, #298. Thanks to Gary Gregory.
  - Bump checkstyle from 8.44 to 9.2.1 #180, #190, #194, #202, #207. Thanks to Dependabot.
  - Bump junit-jupiter from 5.8.0-M1 to 5.9.1 #179, #186, #201, #244, #263. Thanks to Dependabot.
  - Bump jmh-core from 1.32 to 1.36 #176, #208, #229, #285. Thanks to Dependabot.
  - Bump jmh-generator-annprocess from 1.32 to 1.36 #175, #206, #226, #283. Thanks to Dependabot.
  - Bump mockito-core from 3.11.2 to 4.11.0 #187, #197, #204, #212, #230, #237, #251, #259, #284, #292, #297. Thanks to Dependabot, Gary Gregory.
  - Bump maven-pmd-plugin from 3.14.0 to 3.19.0 #184, #219, #238, #254, #258. Thanks to Dependabot.
  - Bump pmd from 6.36.0 to 6.52.0 #173, #189, #193, #199, #227, #233, #214, #236, #240, #247, #255, #273. Thanks to Dependabot, Gary Gregory.
  - Bump opencsv from 5.5.1 to 5.7.1 #182, #221, #260, #281. Thanks to Gary Gregory.
  - Bump spotbugs-maven-plugin from 4.3.0 to 4.7.3.0 #192, #198, #203, #211, #225, #234, #242, #245, #261, #275, #282. Thanks to Dependabot.
  - Bump com.github.spotbugs:spotbugs from 4.5.3 to 4.7.2. Thanks to Gary Gregory.
  - Bump h2 from 1.4.200 to 2.1.214 #200, #205, #213, #239. Thanks to Dependabot.
  - Bump maven-javadoc-plugin from 3.3.0 to 3.4.1. Thanks to Gary Gregory.
  - Bump biz.aQute.bnd:biz.aQute.bndlib from 5.3.0 to 6.3.1. Thanks to Gary Gregory.
  - Bump jacoco-maven-plugin from 0.8.7 to 0.8.8. Thanks to Gary Gregory.
  - Bump japicmp-maven-plugin from 0.15.3 to 0.16.0. Thanks to Gary Gregory.
  - Bump maven-checkstyle-plugin from 3.1.2 to 3.2.0 #253. Thanks to Dependabot.
* Mon Aug 22 2022 Michael Calmer <mc@suse.com>
- reduce macro usage in spec file (jsc#SLE-23217)
* Thu May  5 2022 Fridrich Strba <fstrba@suse.com>
- Generate javadoc with source level 8
* Thu Apr 21 2022 David Anes <david.anes@suse.com>
- Update to version 1.9.0:
  * Many fixes and features. See: https://commons.apache.org/proper/commons-csv/changes-report.html#a1.9.0
- Added apache-commons-csv.rpmlintrc:
  * Ignore summary too long warnings
* Tue Jun 25 2019 Ismail Dönmez <idonmez@suse.com>
- Initial release v1.6 on OBS
